@@ -227,6 +227,12 @@ class Drission(object):
                     self.driver.get(cookie_domain if cookie_domain.startswith('http://')
                                     else f'http://{cookie_domain}')
 
+                # 避免selenium自动添加.后无法正确覆盖已有cookie
+                if cookie['domain'][0] != '.':
+                    c = self.driver.get_cookie(cookie['name'])
+                    if c and c['domain'] == cookie['domain']:
+                        self.driver.delete_cookie(cookie['name'])
+
                 self.driver.add_cookie(cookie)
 
     def _set_session(self, data: dict) -> None:
